@@ -19,7 +19,7 @@ from braket.circuits import (  # noqa: F401
     observables,
     result_types,
 )
-from braket.circuits.angled_gate import AngledGate  # noqa: F401
+from braket.circuits.angled_gate import AngledGate, DoubleAngledGate  # noqa: F401
 from braket.circuits.ascii_circuit_diagram import AsciiCircuitDiagram  # noqa: F401
 from braket.circuits.circuit import Circuit  # noqa: F401
 from braket.circuits.circuit_diagram import CircuitDiagram  # noqa: F401
