@@ -20,6 +20,7 @@ import numpy as np
 from braket.aws import AwsDevice
 from braket.circuits import Circuit, Gate, Instruction, Observable, ResultType
 from braket.circuits.quantum_operator_helpers import get_pauli_eigenvalues
+from braket.circuits.serialization import IRType
 from braket.devices import Device
 from braket.ir.openqasm import Program as OpenQasmProgram
 from braket.tasks import GateModelQuantumTaskResult
@@ -34,11 +35,17 @@ def qubit_ordering_testing(device: Device, run_kwargs: Dict[str, Any]):
     state_110 = Circuit().x(0).x(1).i(2)
     result = device.run(state_110, **run_kwargs).result()
     assert result.measurement_counts.most_common(1)[0][0] == "110"
+    state_110_qasm = state_110.to_ir(ir_type=IRType.OPENQASM)
+    result = device.run(state_110_qasm, **run_kwargs).result()
+    assert result.measurement_counts.most_common(1)[0][0] == "110"
 
     # |001> should get back value of "001"
     state_001 = Circuit().i(0).i(1).x(2)
     result = device.run(state_001, **run_kwargs).result()
     assert result.measurement_counts.most_common(1)[0][0] == "001"
+    state_001_qasm = state_001.to_ir(ir_type=IRType.OPENQASM)
+    result = device.run(state_001_qasm, **run_kwargs).result()
+    assert result.measurement_counts.most_common(1)[0][0] == "001"
 
 
 def no_result_types_testing(
@@ -57,7 +64,10 @@ def no_result_types_testing(
 
 
 def no_result_types_bell_pair_testing(device: Device, run_kwargs: Dict[str, Any]):
-    no_result_types_testing(Circuit().h(0).cnot(0, 1), device, run_kwargs, {"00": 0.5, "11": 0.5})
+    bell = Circuit().h(0).cnot(0, 1)
+    bell_qasm = bell.to_ir(ir_type=IRType.OPENQASM)
+    for task in (bell, bell_qasm):
+        no_result_types_testing(task, device, run_kwargs, {"00": 0.5, "11": 0.5})
 
 
 def result_types_observable_not_in_instructions(device: Device, run_kwargs: Dict[str, Any]):
@@ -70,9 +80,11 @@ def result_types_observable_not_in_instructions(device: Device, run_kwargs: Dict
         .expectation(observable=Observable.X(), target=[2])
         .variance(observable=Observable.Y(), target=[3])
     )
-    result = device.run(bell, **run_kwargs).result()
-    assert np.allclose(result.values[0], 0, **tol)
-    assert np.allclose(result.values[1], 1, **tol)
+    bell_qasm = bell.to_ir(ir_type=IRType.OPENQASM)
+    for task in (bell, bell_qasm):
+        result = device.run(task, **run_kwargs).result()
+        assert np.allclose(result.values[0], 0, **tol)
+        assert np.allclose(result.values[1], 1, **tol)
 
 
 def result_types_zero_shots_bell_pair_testing(
@@ -91,50 +103,59 @@ def result_types_zero_shots_bell_pair_testing(
         circuit.amplitude(["01", "10", "00", "11"])
     if include_state_vector:
         circuit.state_vector()
-    result = device.run(circuit, **run_kwargs).result()
-    assert len(result.result_types) == 3 if include_state_vector else 2
-    assert np.allclose(
-        result.get_value_by_result_type(
-            ResultType.Expectation(observable=Observable.H() @ Observable.X(), target=[0, 1])
-        ),
-        1 / np.sqrt(2),
-    )
-    if include_state_vector:
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
+        assert len(result.result_types) == 3 if include_state_vector else 2
         assert np.allclose(
-            result.get_value_by_result_type(ResultType.StateVector()),
-            np.array([1, 0, 0, 1]) / np.sqrt(2),
+            result.get_value_by_result_type(
+                ResultType.Expectation(observable=Observable.H() @ Observable.X(), target=[0, 1])
+            ),
+            1 / np.sqrt(2),
         )
-    if include_amplitude:
-        assert result.get_value_by_result_type(ResultType.Amplitude(["01", "10", "00", "11"])) == {
-            "01": 0j,
-            "10": 0j,
-            "00": (1 / np.sqrt(2)),
-            "11": (1 / np.sqrt(2)),
-        }
+        if include_state_vector:
+            assert np.allclose(
+                result.get_value_by_result_type(ResultType.StateVector()),
+                np.array([1, 0, 0, 1]) / np.sqrt(2),
+            )
+        if include_amplitude:
+            amplitude = result.get_value_by_result_type(
+                ResultType.Amplitude(["01", "10", "00", "11"])
+            )
+            assert np.isclose(amplitude["01"], 0)
+            assert np.isclose(amplitude["10"], 0)
+            assert np.isclose(amplitude["00"], 1 / np.sqrt(2))
+            assert np.isclose(amplitude["11"], 1 / np.sqrt(2))
 
 
 def result_types_bell_pair_full_probability_testing(device: Device, run_kwargs: Dict[str, Any]):
     shots = run_kwargs["shots"]
     tol = get_tol(shots)
     circuit = Circuit().h(0).cnot(0, 1).probability()
-    result = device.run(circuit, **run_kwargs).result()
-    assert len(result.result_types) == 1
-    assert np.allclose(
-        result.get_value_by_result_type(ResultType.Probability()), np.array([0.5, 0, 0, 0.5]), **tol
-    )
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
+        assert len(result.result_types) == 1
+        assert np.allclose(
+            result.get_value_by_result_type(ResultType.Probability()),
+            np.array([0.5, 0, 0, 0.5]),
+            **tol
+        )
 
 
 def result_types_bell_pair_marginal_probability_testing(device: Device, run_kwargs: Dict[str, Any]):
     shots = run_kwargs["shots"]
     tol = get_tol(shots)
     circuit = Circuit().h(0).cnot(0, 1).probability(0)
-    result = device.run(circuit, **run_kwargs).result()
-    assert len(result.result_types) == 1
-    assert np.allclose(
-        result.get_value_by_result_type(ResultType.Probability(target=0)),
-        np.array([0.5, 0.5]),
-        **tol
-    )
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
+        assert len(result.result_types) == 1
+        assert np.allclose(
+            result.get_value_by_result_type(ResultType.Probability(target=0)),
+            np.array([0.5, 0.5]),
+            **tol
+        )
 
 
 def result_types_nonzero_shots_bell_pair_testing(device: Device, run_kwargs: Dict[str, Any]):
@@ -145,26 +166,30 @@ def result_types_nonzero_shots_bell_pair_testing(device: Device, run_kwargs: Dic
         .expectation(observable=Observable.H() @ Observable.X(), target=[0, 1])
         .sample(observable=Observable.H() @ Observable.X(), target=[0, 1])
     )
-    result = device.run(circuit, **run_kwargs).result()
-    assert len(result.result_types) == 2
-    assert (
-        0.6
-        < result.get_value_by_result_type(
-            ResultType.Expectation(observable=Observable.H() @ Observable.X(), target=[0, 1])
-        )
-        < 0.8
-    )
-    assert (
-        len(
-            result.get_value_by_result_type(
-                ResultType.Sample(observable=Observable.H() @ Observable.X(), target=[0, 1])
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
+        assert len(result.result_types) == 2
+        assert (
+            0.6
+            < result.get_value_by_result_type(
+                ResultType.Expectation(observable=Observable.H() @ Observable.X(), target=[0, 1])
             )
+            < 0.8
+        )
+        assert (
+            len(
+                result.get_value_by_result_type(
+                    ResultType.Sample(observable=Observable.H() @ Observable.X(), target=[0, 1])
+                )
+            )
+            == run_kwargs["shots"]
         )
-        == run_kwargs["shots"]
-    )
 
 
-def result_types_hermitian_testing(device: Device, run_kwargs: Dict[str, Any]):
+def result_types_hermitian_testing(
+    device: Device, run_kwargs: Dict[str, Any], test_program: bool = True
+):
     shots = run_kwargs["shots"]
     theta = 0.543
     array = np.array([[1, 2j], [-2j, 0]])
@@ -177,17 +202,21 @@ def result_types_hermitian_testing(device: Device, run_kwargs: Dict[str, Any]):
     )
     if shots:
         circuit.add_result_type(ResultType.Sample(Observable.Hermitian(array), 0))
-    result = device.run(circuit, **run_kwargs).result()
+    tasks = (circuit,) if not test_program else (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
 
-    expected_mean = 2 * np.sin(theta) + 0.5 * np.cos(theta) + 0.5
-    expected_var = 0.25 * (np.sin(theta) - 4 * np.cos(theta)) ** 2
-    expected_eigs = np.linalg.eigvalsh(array)
-    assert_variance_expectation_sample_result(
-        result, shots, expected_var, expected_mean, expected_eigs
-    )
+        expected_mean = 2 * np.sin(theta) + 0.5 * np.cos(theta) + 0.5
+        expected_var = 0.25 * (np.sin(theta) - 4 * np.cos(theta)) ** 2
+        expected_eigs = np.linalg.eigvalsh(array)
+        assert_variance_expectation_sample_result(
+            result, shots, expected_var, expected_mean, expected_eigs
+        )
 
 
-def result_types_all_selected_testing(device: Device, run_kwargs: Dict[str, Any]):
+def result_types_all_selected_testing(
+    device: Device, run_kwargs: Dict[str, Any], test_program: bool = True
+):
     shots = run_kwargs["shots"]
     theta = 0.543
     array = np.array([[1, 2j], [-2j, 0]])
@@ -201,15 +230,19 @@ def result_types_all_selected_testing(device: Device, run_kwargs: Dict[str, Any]
     )
     if shots:
         circuit.add_result_type(ResultType.Sample(Observable.Hermitian(array), 1))
-    result = device.run(circuit, **run_kwargs).result()
 
-    expected_mean = 2 * np.sin(theta) + 0.5 * np.cos(theta) + 0.5
-    var = 0.25 * (np.sin(theta) - 4 * np.cos(theta)) ** 2
-    expected_var = [var, var]
-    expected_eigs = np.linalg.eigvalsh(array)
-    assert_variance_expectation_sample_result(
-        result, shots, expected_var, expected_mean, expected_eigs
-    )
+    tasks = (circuit,) if not test_program else (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
+
+        expected_mean = 2 * np.sin(theta) + 0.5 * np.cos(theta) + 0.5
+        var = 0.25 * (np.sin(theta) - 4 * np.cos(theta)) ** 2
+        expected_var = [var, var]
+        expected_eigs = np.linalg.eigvalsh(array)
+        assert_variance_expectation_sample_result(
+            result, shots, expected_var, expected_mean, expected_eigs
+        )
 
 
 def get_result_types_three_qubit_circuit(theta, phi, varphi, obs, obs_targets, shots) -> Circuit:
@@ -255,22 +288,24 @@ def result_types_tensor_x_y_testing(device: Device, run_kwargs: Dict[str, Any]):
     obs = Observable.X() @ Observable.Y()
     obs_targets = [0, 2]
     circuit = get_result_types_three_qubit_circuit(theta, phi, varphi, obs, obs_targets, shots)
-    result = device.run(circuit, **run_kwargs).result()
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
 
-    expected_mean = np.sin(theta) * np.sin(phi) * np.sin(varphi)
-    expected_var = (
-        8 * np.sin(theta) ** 2 * np.cos(2 * varphi) * np.sin(phi) ** 2
-        - np.cos(2 * (theta - phi))
-        - np.cos(2 * (theta + phi))
-        + 2 * np.cos(2 * theta)
-        + 2 * np.cos(2 * phi)
-        + 14
-    ) / 16
-    expected_eigs = get_pauli_eigenvalues(1)
+        expected_mean = np.sin(theta) * np.sin(phi) * np.sin(varphi)
+        expected_var = (
+            8 * np.sin(theta) ** 2 * np.cos(2 * varphi) * np.sin(phi) ** 2
+            - np.cos(2 * (theta - phi))
+            - np.cos(2 * (theta + phi))
+            + 2 * np.cos(2 * theta)
+            + 2 * np.cos(2 * phi)
+            + 14
+        ) / 16
+        expected_eigs = get_pauli_eigenvalues(1)
 
-    assert_variance_expectation_sample_result(
-        result, shots, expected_var, expected_mean, expected_eigs
-    )
+        assert_variance_expectation_sample_result(
+            result, shots, expected_var, expected_mean, expected_eigs
+        )
 
 
 def result_types_tensor_z_z_testing(device: Device, run_kwargs: Dict[str, Any]):
@@ -281,15 +316,17 @@ def result_types_tensor_z_z_testing(device: Device, run_kwargs: Dict[str, Any]):
     obs = Observable.Z() @ Observable.Z()
     obs_targets = [0, 2]
     circuit = get_result_types_three_qubit_circuit(theta, phi, varphi, obs, obs_targets, shots)
-    result = device.run(circuit, **run_kwargs).result()
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
 
-    expected_mean = 0.849694136476246
-    expected_var = 0.27801987443788634
-    expected_eigs = get_pauli_eigenvalues(1)
+        expected_mean = 0.849694136476246
+        expected_var = 0.27801987443788634
+        expected_eigs = get_pauli_eigenvalues(1)
 
-    assert_variance_expectation_sample_result(
-        result, shots, expected_var, expected_mean, expected_eigs
-    )
+        assert_variance_expectation_sample_result(
+            result, shots, expected_var, expected_mean, expected_eigs
+        )
 
 
 def result_types_tensor_hermitian_hermitian_testing(device: Device, run_kwargs: Dict[str, Any]):
@@ -309,15 +346,17 @@ def result_types_tensor_hermitian_hermitian_testing(device: Device, run_kwargs:
     obs = Observable.Hermitian(matrix1) @ Observable.Hermitian(matrix2)
     obs_targets = [0, 1, 2]
     circuit = get_result_types_three_qubit_circuit(theta, phi, varphi, obs, obs_targets, shots)
-    result = device.run(circuit, **run_kwargs).result()
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
 
-    expected_mean = -4.30215023196904
-    expected_var = 370.71292282796804
-    expected_eigs = np.array([-70.90875406, -31.04969387, 0, 3.26468993, 38.693758])
+        expected_mean = -4.30215023196904
+        expected_var = 370.71292282796804
+        expected_eigs = np.array([-70.90875406, -31.04969387, 0, 3.26468993, 38.693758])
 
-    assert_variance_expectation_sample_result(
-        result, shots, expected_var, expected_mean, expected_eigs
-    )
+        assert_variance_expectation_sample_result(
+            result, shots, expected_var, expected_mean, expected_eigs
+        )
 
 
 def result_types_tensor_z_h_y_testing(device: Device, run_kwargs: Dict[str, Any]):
@@ -328,20 +367,23 @@ def result_types_tensor_z_h_y_testing(device: Device, run_kwargs: Dict[str, Any]
     obs = Observable.Z() @ Observable.H() @ Observable.Y()
     obs_targets = [0, 1, 2]
     circuit = get_result_types_three_qubit_circuit(theta, phi, varphi, obs, obs_targets, shots)
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
 
-    result = device.run(circuit, **run_kwargs).result()
-
-    expected_mean = -(np.cos(varphi) * np.sin(phi) + np.sin(varphi) * np.cos(theta)) / np.sqrt(2)
-    expected_var = (
-        3
-        + np.cos(2 * phi) * np.cos(varphi) ** 2
-        - np.cos(2 * theta) * np.sin(varphi) ** 2
-        - 2 * np.cos(theta) * np.sin(phi) * np.sin(2 * varphi)
-    ) / 4
-    expected_eigs = get_pauli_eigenvalues(1)
-    assert_variance_expectation_sample_result(
-        result, shots, expected_var, expected_mean, expected_eigs
-    )
+        expected_mean = -(np.cos(varphi) * np.sin(phi) + np.sin(varphi) * np.cos(theta)) / np.sqrt(
+            2
+        )
+        expected_var = (
+            3
+            + np.cos(2 * phi) * np.cos(varphi) ** 2
+            - np.cos(2 * theta) * np.sin(varphi) ** 2
+            - 2 * np.cos(theta) * np.sin(phi) * np.sin(2 * varphi)
+        ) / 4
+        expected_eigs = get_pauli_eigenvalues(1)
+        assert_variance_expectation_sample_result(
+            result, shots, expected_var, expected_mean, expected_eigs
+        )
 
 
 def result_types_tensor_z_hermitian_testing(device: Device, run_kwargs: Dict[str, Any]):
@@ -360,51 +402,52 @@ def result_types_tensor_z_hermitian_testing(device: Device, run_kwargs: Dict[str
     obs = Observable.Z() @ Observable.Hermitian(array)
     obs_targets = [0, 1, 2]
     circuit = get_result_types_three_qubit_circuit(theta, phi, varphi, obs, obs_targets, shots)
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
 
-    result = device.run(circuit, **run_kwargs).result()
-
-    expected_mean = 0.5 * (
-        -6 * np.cos(theta) * (np.cos(varphi) + 1)
-        - 2 * np.sin(varphi) * (np.cos(theta) + np.sin(phi) - 2 * np.cos(phi))
-        + 3 * np.cos(varphi) * np.sin(phi)
-        + np.sin(phi)
-    )
-    expected_var = (
-        1057
-        - np.cos(2 * phi)
-        + 12 * (27 + np.cos(2 * phi)) * np.cos(varphi)
-        - 2 * np.cos(2 * varphi) * np.sin(phi) * (16 * np.cos(phi) + 21 * np.sin(phi))
-        + 16 * np.sin(2 * phi)
-        - 8 * (-17 + np.cos(2 * phi) + 2 * np.sin(2 * phi)) * np.sin(varphi)
-        - 8 * np.cos(2 * theta) * (3 + 3 * np.cos(varphi) + np.sin(varphi)) ** 2
-        - 24 * np.cos(phi) * (np.cos(phi) + 2 * np.sin(phi)) * np.sin(2 * varphi)
-        - 8
-        * np.cos(theta)
-        * (
-            4
-            * np.cos(phi)
+        expected_mean = 0.5 * (
+            -6 * np.cos(theta) * (np.cos(varphi) + 1)
+            - 2 * np.sin(varphi) * (np.cos(theta) + np.sin(phi) - 2 * np.cos(phi))
+            + 3 * np.cos(varphi) * np.sin(phi)
+            + np.sin(phi)
+        )
+        expected_var = (
+            1057
+            - np.cos(2 * phi)
+            + 12 * (27 + np.cos(2 * phi)) * np.cos(varphi)
+            - 2 * np.cos(2 * varphi) * np.sin(phi) * (16 * np.cos(phi) + 21 * np.sin(phi))
+            + 16 * np.sin(2 * phi)
+            - 8 * (-17 + np.cos(2 * phi) + 2 * np.sin(2 * phi)) * np.sin(varphi)
+            - 8 * np.cos(2 * theta) * (3 + 3 * np.cos(varphi) + np.sin(varphi)) ** 2
+            - 24 * np.cos(phi) * (np.cos(phi) + 2 * np.sin(phi)) * np.sin(2 * varphi)
+            - 8
+            * np.cos(theta)
             * (
                 4
-                + 8 * np.cos(varphi)
-                + np.cos(2 * varphi)
-                - (1 + 6 * np.cos(varphi)) * np.sin(varphi)
+                * np.cos(phi)
+                * (
+                    4
+                    + 8 * np.cos(varphi)
+                    + np.cos(2 * varphi)
+                    - (1 + 6 * np.cos(varphi)) * np.sin(varphi)
+                )
+                + np.sin(phi)
+                * (
+                    15
+                    + 8 * np.cos(varphi)
+                    - 11 * np.cos(2 * varphi)
+                    + 42 * np.sin(varphi)
+                    + 3 * np.sin(2 * varphi)
+                )
             )
-            + np.sin(phi)
-            * (
-                15
-                + 8 * np.cos(varphi)
-                - 11 * np.cos(2 * varphi)
-                + 42 * np.sin(varphi)
-                + 3 * np.sin(2 * varphi)
-            )
-        )
-    ) / 16
+        ) / 16
 
-    z_array = np.diag([1, -1])
-    expected_eigs = np.linalg.eigvalsh(np.kron(z_array, array))
-    assert_variance_expectation_sample_result(
-        result, shots, expected_var, expected_mean, expected_eigs
-    )
+        z_array = np.diag([1, -1])
+        expected_eigs = np.linalg.eigvalsh(np.kron(z_array, array))
+        assert_variance_expectation_sample_result(
+            result, shots, expected_var, expected_mean, expected_eigs
+        )
 
 
 def result_types_tensor_y_hermitian_testing(device: Device, run_kwargs: Dict[str, Any]):
@@ -423,16 +466,17 @@ def result_types_tensor_y_hermitian_testing(device: Device, run_kwargs: Dict[str
     obs = Observable.Y() @ Observable.Hermitian(array)
     obs_targets = [0, 1, 2]
     circuit = get_result_types_three_qubit_circuit(theta, phi, varphi, obs, obs_targets, shots)
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
 
-    result = device.run(circuit, **run_kwargs).result()
-
-    expected_mean = 1.4499810303182408
-    expected_var = 74.03174647518193
-    y_array = np.array([[0, -1j], [1j, 0]])
-    expected_eigs = np.linalg.eigvalsh(np.kron(y_array, array))
-    assert_variance_expectation_sample_result(
-        result, shots, expected_var, expected_mean, expected_eigs
-    )
+        expected_mean = 1.4499810303182408
+        expected_var = 74.03174647518193
+        y_array = np.array([[0, -1j], [1j, 0]])
+        expected_eigs = np.linalg.eigvalsh(np.kron(y_array, array))
+        assert_variance_expectation_sample_result(
+            result, shots, expected_var, expected_mean, expected_eigs
+        )
 
 
 def result_types_noncommuting_testing(device: Device, run_kwargs: Dict[str, Any]):
@@ -459,24 +503,26 @@ def result_types_noncommuting_testing(device: Device, run_kwargs: Dict[str, Any]
         .expectation(obs2, obs2_targets)
         .expectation(obs3, obs3_targets)
     )
-    result = device.run(circuit, **run_kwargs).result()
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
 
-    expected_mean1 = np.sin(theta) * np.sin(phi) * np.sin(varphi)
-    expected_var1 = (
-        8 * np.sin(theta) ** 2 * np.cos(2 * varphi) * np.sin(phi) ** 2
-        - np.cos(2 * (theta - phi))
-        - np.cos(2 * (theta + phi))
-        + 2 * np.cos(2 * theta)
-        + 2 * np.cos(2 * phi)
-        + 14
-    ) / 16
+        expected_mean1 = np.sin(theta) * np.sin(phi) * np.sin(varphi)
+        expected_var1 = (
+            8 * np.sin(theta) ** 2 * np.cos(2 * varphi) * np.sin(phi) ** 2
+            - np.cos(2 * (theta - phi))
+            - np.cos(2 * (theta + phi))
+            + 2 * np.cos(2 * theta)
+            + 2 * np.cos(2 * phi)
+            + 14
+        ) / 16
 
-    expected_mean2 = 0.849694136476246
-    expected_mean3 = 1.4499810303182408
-    assert np.allclose(result.values[0], expected_var1)
-    assert np.allclose(result.values[1], expected_mean1)
-    assert np.allclose(result.values[2], expected_mean2)
-    assert np.allclose(result.values[3], expected_mean3)
+        expected_mean2 = 0.849694136476246
+        expected_mean3 = 1.4499810303182408
+        assert np.allclose(result.values[0], expected_var1)
+        assert np.allclose(result.values[1], expected_mean1)
+        assert np.allclose(result.values[2], expected_mean2)
+        assert np.allclose(result.values[3], expected_mean3)
 
 
 def result_types_noncommuting_flipped_targets_testing(device: Device, run_kwargs: Dict[str, Any]):
@@ -487,9 +533,11 @@ def result_types_noncommuting_flipped_targets_testing(device: Device, run_kwargs
         .expectation(observable=Observable.H() @ Observable.X(), target=[0, 1])
         .expectation(observable=Observable.H() @ Observable.X(), target=[1, 0])
     )
-    result = device.run(circuit, shots=0, **run_kwargs).result()
-    assert np.allclose(result.values[0], np.sqrt(2) / 2)
-    assert np.allclose(result.values[1], np.sqrt(2) / 2)
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, shots=0, **run_kwargs).result()
+        assert np.allclose(result.values[0], np.sqrt(2) / 2)
+        assert np.allclose(result.values[1], np.sqrt(2) / 2)
 
 
 def result_types_noncommuting_all(device: Device, run_kwargs: Dict[str, Any]):
@@ -501,9 +549,11 @@ def result_types_noncommuting_all(device: Device, run_kwargs: Dict[str, Any]):
         .expectation(observable=Observable.Hermitian(array))
         .expectation(observable=Observable.X())
     )
-    result = device.run(circuit, shots=0, **run_kwargs).result()
-    assert np.allclose(result.values[0], [0.5, 0.5])
-    assert np.allclose(result.values[1], [0, 0])
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, shots=0, **run_kwargs).result()
+        assert np.allclose(result.values[0], [0.5, 0.5])
+        assert np.allclose(result.values[1], [0, 0])
 
 
 def multithreaded_bell_pair_testing(device: Device, run_kwargs: Dict[str, Any]):
@@ -518,28 +568,32 @@ def multithreaded_bell_pair_testing(device: Device, run_kwargs: Dict[str, Any]):
     futures = []
     num_threads = 2
 
-    with concurrent.futures.ThreadPoolExecutor() as executor:
-        for _ in range(num_threads):
-            future = executor.submit(run_circuit, bell)
-            futures.append(future)
-    for future in futures:
-        result = future.result()
-        assert np.allclose(result.measurement_probabilities["00"], 0.5, **tol)
-        assert np.allclose(result.measurement_probabilities["11"], 0.5, **tol)
-        assert len(result.measurements) == shots
+    tasks = (bell, bell.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        with concurrent.futures.ThreadPoolExecutor() as executor:
+            for _ in range(num_threads):
+                future = executor.submit(run_circuit, task)
+                futures.append(future)
+        for future in futures:
+            result = future.result()
+            assert np.allclose(result.measurement_probabilities["00"], 0.5, **tol)
+            assert np.allclose(result.measurement_probabilities["11"], 0.5, **tol)
+            assert len(result.measurements) == shots
 
 
 def noisy_circuit_1qubit_noise_full_probability(device: Device, run_kwargs: Dict[str, Any]):
     shots = run_kwargs["shots"]
     tol = get_tol(shots)
     circuit = Circuit().x(0).x(1).bit_flip(0, 0.1).probability()
-    result = device.run(circuit, **run_kwargs).result()
-    assert len(result.result_types) == 1
-    assert np.allclose(
-        result.get_value_by_result_type(ResultType.Probability()),
-        np.array([0.0, 0.1, 0, 0.9]),
-        **tol
-    )
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
+        assert len(result.result_types) == 1
+        assert np.allclose(
+            result.get_value_by_result_type(ResultType.Probability()),
+            np.array([0.0, 0.1, 0, 0.9]),
+            **tol
+        )
 
 
 def noisy_circuit_2qubit_noise_full_probability(device: Device, run_kwargs: Dict[str, Any]):
@@ -550,27 +604,30 @@ def noisy_circuit_2qubit_noise_full_probability(device: Device, run_kwargs: Dict
         0.1
     )
     circuit = Circuit().x(0).x(1).kraus((0, 1), [K0, K1]).probability()
-    result = device.run(circuit, **run_kwargs).result()
-    assert len(result.result_types) == 1
-    assert np.allclose(
-        result.get_value_by_result_type(ResultType.Probability()),
-        np.array([0.1, 0.0, 0, 0.9]),
-        **tol
-    )
+    tasks = (circuit, circuit.to_ir(ir_type=IRType.OPENQASM))
+    for task in tasks:
+        result = device.run(task, **run_kwargs).result()
+        assert len(result.result_types) == 1
+        assert np.allclose(
+            result.get_value_by_result_type(ResultType.Probability()),
+            np.array([0.1, 0.0, 0, 0.9]),
+            **tol
+        )
 
 
 def batch_bell_pair_testing(device: AwsDevice, run_kwargs: Dict[str, Any]):
     shots = run_kwargs["shots"]
     tol = get_tol(shots)
     circuits = [Circuit().h(0).cnot(0, 1) for _ in range(10)]
-
-    batch = device.run_batch(circuits, max_parallel=5, **run_kwargs)
-    results = batch.results()
-    for result in results:
-        assert np.allclose(result.measurement_probabilities["00"], 0.5, **tol)
-        assert np.allclose(result.measurement_probabilities["11"], 0.5, **tol)
-        assert len(result.measurements) == shots
-    assert [task.result() for task in batch.tasks] == results
+    tasks_list = (circuits, [circuit.to_ir(ir_type=IRType.OPENQASM) for circuit in circuits])
+    for tasks in tasks_list:
+        batch = device.run_batch(tasks, max_parallel=5, **run_kwargs)
+        results = batch.results()
+        for result in results:
+            assert np.allclose(result.measurement_probabilities["00"], 0.5, **tol)
+            assert np.allclose(result.measurement_probabilities["11"], 0.5, **tol)
+            assert len(result.measurements) == shots
+        assert [task.result() for task in batch.tasks] == results
 
 
 def bell_pair_openqasm_testing(device: AwsDevice, run_kwargs: Dict[str, Any]):
@@ -583,9 +640,12 @@ def bell_pair_openqasm_testing(device: AwsDevice, run_kwargs: Dict[str, Any]):
         "c[0] = measure q[0];"
         "c[1] = measure q[1];"
     )
-    no_result_types_testing(
-        OpenQasmProgram(source=openqasm_string), device, run_kwargs, {"00": 0.5, "11": 0.5}
-    )
+    hardcoded_openqasm = OpenQasmProgram(source=openqasm_string)
+    circuit = Circuit().h(0).cnot(0, 1)
+    generated_openqasm = circuit.to_ir(ir_type=IRType.OPENQASM)
+
+    for program in hardcoded_openqasm, generated_openqasm:
+        no_result_types_testing(program, device, run_kwargs, {"00": 0.5, "11": 0.5})
 
 
 def openqasm_noisy_circuit_1qubit_noise_full_probability(
@@ -601,13 +661,18 @@ def openqasm_noisy_circuit_1qubit_noise_full_probability(
         "#pragma braket noise bit_flip(0.1) q[0]"
         "#pragma braket result probability q[0], q[1]"
     )
-    result = device.run(OpenQasmProgram(source=openqasm_string), **run_kwargs).result()
-    assert len(result.result_types) == 1
-    assert np.allclose(
-        result.get_value_by_result_type(ResultType.Probability(target=[0, 1])),
-        np.array([0.0, 0.1, 0, 0.9]),
-        **tol
-    )
+    hardcoded_openqasm = OpenQasmProgram(source=openqasm_string)
+    circuit = Circuit().x(0).x(1).bit_flip(0, 0.1).probability([0, 1])
+    generated_openqasm = circuit.to_ir(ir_type=IRType.OPENQASM)
+
+    for program in hardcoded_openqasm, generated_openqasm:
+        result = device.run(program, **run_kwargs).result()
+        assert len(result.result_types) == 1
+        assert np.allclose(
+            result.get_value_by_result_type(ResultType.Probability(target=[0, 1])),
+            np.array([0.0, 0.1, 0, 0.9]),
+            **tol
+        )
 
 
 def openqasm_result_types_bell_pair_testing(device: Device, run_kwargs: Dict[str, Any]):
@@ -619,23 +684,34 @@ def openqasm_result_types_bell_pair_testing(device: Device, run_kwargs: Dict[str
         "#pragma braket result expectation h(q[0]) @ x(q[1])"
         "#pragma braket result sample h(q[0]) @ x(q[1])"
     )
-    result = device.run(OpenQasmProgram(source=openqasm_string), **run_kwargs).result()
-    assert len(result.result_types) == 2
-    assert (
-        0.6
-        < result.get_value_by_result_type(
-            ResultType.Expectation(observable=Observable.H() @ Observable.X(), target=[0, 1])
-        )
-        < 0.8
+    hardcoded_openqasm = OpenQasmProgram(source=openqasm_string)
+    circuit = (
+        Circuit()
+        .h(0)
+        .cnot(0, 1)
+        .expectation(Observable.H() @ Observable.X(), (0, 1))
+        .sample(Observable.H() @ Observable.X(), (0, 1))
     )
-    assert (
-        len(
-            result.get_value_by_result_type(
-                ResultType.Sample(observable=Observable.H() @ Observable.X(), target=[0, 1])
+    generated_openqasm = circuit.to_ir(ir_type=IRType.OPENQASM)
+
+    for program in hardcoded_openqasm, generated_openqasm:
+        result = device.run(program, **run_kwargs).result()
+        assert len(result.result_types) == 2
+        assert (
+            0.6
+            < result.get_value_by_result_type(
+                ResultType.Expectation(observable=Observable.H() @ Observable.X(), target=[0, 1])
             )
+            < 0.8
+        )
+        assert (
+            len(
+                result.get_value_by_result_type(
+                    ResultType.Sample(observable=Observable.H() @ Observable.X(), target=[0, 1])
+                )
+            )
+            == run_kwargs["shots"]
         )
-        == run_kwargs["shots"]
-    )
 
 
 def many_layers(n_qubits: int, n_layers: int) -> Circuit:
